@@ -56,13 +56,13 @@ import java.io.InputStreamReader;
 import java.nio.charset.StandardCharsets;
 import java.util.Arrays;
 import com.openexchange.exception.OXException;
-import com.openexchange.groupware.ldap.User;
 import com.openexchange.java.Strings;
 import com.openexchange.passwordchange.PasswordChangeEvent;
 import com.openexchange.passwordchange.PasswordChangeService;
 import com.openexchange.server.ServiceExceptionCode;
 import com.openexchange.server.ServiceLookup;
 import com.openexchange.tools.encoding.Base64;
+import com.openexchange.user.User;
 import com.openexchange.user.UserService;
 
 /**
@@ -179,10 +179,10 @@ public final class ScriptPasswordChange extends PasswordChangeService {
                         throw ServiceExceptionCode.IO_ERROR.create();
                 }
             }
-        } catch (final IOException e) {
+        } catch (IOException e) {
             LOG.error("IO error while changing password for user {} in context {}\n", usern, cid, e);
             throw ServiceExceptionCode.IO_ERROR.create(e);
-        } catch (final InterruptedException e) {
+        } catch (InterruptedException e) {
             // Restore the interrupted status; see http://www.ibm.com/developerworks/java/library/j-jtp05236/index.html
             Thread.currentThread().interrupt();
             LOG.error("Error while changing password for user {} in context {}\n", usern, cid, e);
